Exports dataset to a data.frame, with options to save it as an R object, and export it as a .csv or .xlsx file.
ExportDataset(dataset = NULL, text = NULL, metadata = NULL, exportRds = FALSE, exportRdata = FALSE, exportCsv = FALSE, exportXlsx = FALSE, project = NULL, website = NULL)
| dataset | A 'castarter' dataset. |
|---|---|
| text | A character vector typically created with ExtractText(). |
| metadata | A data.frame typically created with ExportMetadata(). Number of rows must be the same as the number of text items in `text`. |
| exportCsv | If equal to TRUE, exports the complete dataset in the .csv file format in the Dataset sub-folder. |
| exportXlsx | If equal to TRUE, exports the complete dataset in the .xlsx file format in the Dataset sub-folder. |
| project | Name of 'castarter' project. Must correspond to the name of a folder in the current working directory. |
| website | Name of a website included in a 'castarter' project. Must correspond to the name of a sub-folder of the project folder. |
| exportRdsIf | equal to TRUE, exports the complete dataset in R's .rds file format in the Dataset sub-folder. |
A data.frame, a 'castarter' dataset.
# NOT RUN { dataset <- ExportDataset(text, metadata, project, website) # }