Exports metadata to a vector, csv or xlsx file.
ExportMetadata(id, dates, titles, language, links, exportCsv = FALSE, exportXlsx = FALSE, accordingToDate = FALSE, ignoreNAdates = FALSE, project = NULL, website = NULL)
| id | A vector of integers, usually created with `ExtractId()`. |
|---|---|
| dates | A vector of dates, usually created with `ExtractDates()`. |
| titles | A chacter vector, usually created with `ExtractTitles()`. |
| language | A chacter vector, usually of length 1 (e.g. \"english"). It can be of the same length of other vectors when multiple languages are included. |
| links | A chacter vector, usually created with `ExtractLinks()`. Only links matching the given `id` are included in the metadata. |
| exportCsv | If equal to TRUE, exports the complete dataset in the .xlsx file format in the Dataset sub-folder. |
| exportXlsx | If equal to TRUE, exports the metadata in the .xlsx file format in the Dataset sub-folder. |
| project | Name of 'castarter' project. Must correspond to the name of a folder in the current working directory. |
| website | Name of a website included in a 'castarter' project. Must correspond to the name of a sub-folder of the project folder. |
A vector of the data.frame class.
# NOT RUN { metadata <- ExportMetadata(id, dates, titles, language, links) # }