R/preliminary.R
LoadLatest.RdUsed in combination with load, it loads the most recent workspace saved for a given website based on the date included in the filename of the .Rdata file.
LoadLatest(project = NULL, website = NULL)
| project | Name of 'castarter' project. Must correspond to the name of a folder in the current working directory. |
|---|---|
| website | Name of a website included in a 'castarter' project. Must correspond to the name of a sub-folder of the project folder. |
# NOT RUN { load(LoadLatest(project, website)) # }